==> 6.4.6.tar.gz: lib/XWidgets/XBTN/XBtnBase.dart <==
part of xwidgetbase;

class XBtnbase extends StatelessWidget {
  final String? label;
  final TextStyle? styleLabel;
  final AlignmentGeometry? alignmentLabel;

  ///Da il colore a tutti i tipi di testo
  final Color? textColor;

  final IconData? icon;
  final Color? iconColor;
  final double? iconSize;

  final double? widthBTN;
  final double? heightBTN;
  final Color? colorBTN;
  final Decoration? decorationBTN;
  final double? radiusBorder;
  final double? elevation;
  final double? widthAreaOfIcon;
  final EdgeInsets? paddingBTNContent;

  final String? nameOfPageToGo;
  final BuildContext? buildContextOfPage;
  final Function()? onPressed;
  final TextAlign? textAlignLabel;

  XBtnbase({
    this.label = "",
    this.decorationBTN,
    this.paddingBTNContent,
    this.radiusBorder,
    this.widthBTN = 100,
    this.heightBTN = 50,
    this.alignmentLabel,
    this.elevation,
    this.buildContextOfPage,
    this.icon,
    this.textAlignLabel,
    this.nameOfPageToGo = "",
    this.styleLabel,
    this.iconSize = 28,
    this.colorBTN = Colors.black,
    this.textColor,
    this.iconColor = Colors.black,
    this.onPressed,
    this.widthAreaOfIcon,
  });

  static onlyBorderAndLabel({
    String? label = "Inserisci Label",
    double? widthBTN = 250,
    double? heightBTN = 40,
    Function()? onPressed,
    Color? colorBorderAndLabel = Colors.greenAccent,
    double? widthBorder = 2,
    Color? colorBackGround,
    Color? labelColor = Colors.greenAccent,
    TextAlign? textAlignLabel = TextAlign.center,
    double? borderRadius = 5,
  }) {
    return XBtnbase(
      elevation: 0,
      widthBTN: widthBTN,
      heightBTN: heightBTN,
      textAlignLabel: textAlignLabel,
      label: label,
      styleLabel: XStyles.xStyTextForLabel(labelColor ?? colorBorderAndLabel),
      decorationBTN: XDecoration.onlyBorder(
        borderRadius: borderRadius!,
        colorBackGround: colorBackGround ?? Colors.grey[900],
        widthBorder: widthBorder!,
        colorBorder: colorBorderAndLabel!,
      ),
      onPressed: onPressed,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        width: widthBTN,
        height: heightBTN,
        alignment: Alignment.center,
        decoration: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.grey, borderRadius: BorderRadius.all(Radius.circular(radiusBorder ?? 0))),
        child: ElevatedButton(
          style: ElevatedButton.styleFrom(elevation: elevation ?? 10, primary: Colors.transparent, alignment: Alignment.centerLeft, padding: paddingBTNContent ?? EdgeInsets.all(5)),
          onPressed: nameOfPageToGo != ""
              ? () {
                  Navigator.pushNamed(buildContextOfPage!, nameOfPageToGo!);
                }
              : onPressed,
          child: icon != null && (label == null || label == "")
              ? Container(
                  color: Colors.transparent,
                  height: heightBTN!,
                  width: widthBTN!,
                  child: Row(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.center, children: [
                    Container(
                      color: Colors.transparent,
                      alignment: Alignment.center,
                      child: Icon(
                        icon,
                        color: iconColor,
                        size: iconSize,
                      ),
                    ),
                  ]))
              : Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    icon != null
                        ? Container(
                            color: Colors.transparent,
                            width: widthAreaOfIcon ?? null,
                            alignment: Alignment.center,
                            child: Icon(
                              icon,
                              color: iconColor,
                              size: iconSize,
                            ))
                        : Container(),
                    label != null
                        ? Expanded(
                            child: Container(
                                color: Colors.transparent,
                                alignment: alignmentLabel ?? Alignment.center,
                                child: Text(
                                  label!,
                                  style: styleLabel ?? XStyles.xStyleText(fontSize: 13, colorText: textColor),
                                  textAlign: textAlignLabel ?? TextAlign.center,
                                )))
                        : Container(),
                  ],
                ),
        ));
  }
}

==> 7.0.6.tar.gz: lib/XWidgets/XBTN/XBtnBase.dart <==
part of xwidgetbase;

class XBtnbase extends StatelessWidget {
  final String? label;
  final TextStyle? styleLabel;
  final AlignmentGeometry? alignmentLabel;

  ///Da il colore a tutti i tipi di testo
  final Color? textColor;

  final IconData? icon;
  final Color? iconColor;
  final double? iconSize;

  final double? widthBTN;
  final double? heightBTN;
  final Color? colorBTN;
  final Decoration? decorationBTN;
  final double? radiusBorder;
  final double? elevation;
  final double? widthAreaOfIcon;
  final EdgeInsets? paddingBTNContent;

  final String? nameOfPageToGo;
  final BuildContext? buildContextOfPage;
  final Function()? onPressed;
  final TextAlign? textAlignLabel;

  XBtnbase({
    this.label = "",
    this.decorationBTN,
    this.paddingBTNContent,
    this.radiusBorder,
    this.widthBTN = 100,
    this.heightBTN = 50,
    this.alignmentLabel,
    this.elevation,
    this.buildContextOfPage,
    this.icon,
    this.textAlignLabel,
    this.nameOfPageToGo = "",
    this.styleLabel,
    this.iconSize = 28,
    this.colorBTN = Colors.black,
    this.textColor,
    this.iconColor = Colors.black,
    this.onPressed,
    this.widthAreaOfIcon,
  });

  static onlyBorderAndLabel({
    String? label = "Inserisci Label",
    double? widthBTN = 250,
    double? heightBTN = 40,
    Function()? onPressed,
    Color? colorBorder = Colors.greenAccent,
    double? widthBorder = 2,
    Color? colorBackGround,
    Color? labelColor = Colors.greenAccent,
    TextAlign? textAlignLabel = TextAlign.center,
    double? borderRadius = 5,
  }) {
    return XBtnbase(
      elevation: 0,
      widthBTN: widthBTN,
      heightBTN: heightBTN,
      textAlignLabel: textAlignLabel,
      label: label,
      styleLabel: XStyles.xStyTextForLabel(labelColor ?? colorBorder),
      decorationBTN: XDecoration.onlyBorder(
        borderRadius: borderRadius!,
        colorBackGround: colorBackGround ?? Colors.grey[900],
        widthBorder: widthBorder!,
        colorBorder: colorBorder!,
      ),
      onPressed: onPressed,
    );
  }

  static ForMenu({
    String? label = "Inserisci Label",
    double? widthBTN = 250,
    double? heightBTN = 40,
    Function()? onPressed,
    Color? colorBorder = Colors.greenAccent,
    double? widthBorder = 2,
    Color? colorBackGround,
    Color? labelColor = Colors.greenAccent,
    TextAlign? textAlignLabel = TextAlign.center,
    double? borderRadius = 5,
  }) {
    return XBtnbase.onlyBorderAndLabel(
      widthBTN: 250,
      heightBTN: 80,
      labelColor: labelColor,
      colorBorder: colorBorder,
      onPressed: onPressed,
      label: label,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        width: widthBTN,
        height: heightBTN,
        alignment: Alignment.center,
        decoration: decorationBTN ?? BoxDecoration(color: colorBTN ?? Colors.grey, borderRadius: BorderRadius.all(Radius.circular(radiusBorder ?? 0))),
        child: ElevatedButton(
          style: ElevatedButton.styleFrom(elevation: elevation ?? 10, primary: Colors.transparent, alignment: Alignment.centerLeft, padding: paddingBTNContent ?? EdgeInsets.all(5)),
          onPressed: nameOfPageToGo != ""
              ? () {
                  Navigator.pushNamed(buildContextOfPage!, nameOfPageToGo!);
                }
              : onPressed,
          child: icon != null && (label == null || label == "")
              ? Container(
                  color: Colors.transparent,
                  height: heightBTN!,
                  width: widthBTN!,
                  child: Row(mainAxisSize: MainAxisSize.min, crossAxisAlignment: CrossAxisAlignment.center, mainAxisAlignment: MainAxisAlignment.center, children: [
                    Container(
                      color: Colors.transparent,
                      alignment: Alignment.center,
                      child: Icon(
                        icon,
                        color: iconColor,
                        size: iconSize,
                      ),
                    ),
                  ]))
              : Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    icon != null
                        ? Container(
                            color: Colors.transparent,
                            width: widthAreaOfIcon ?? null,
                            alignment: Alignment.center,
                            child: Icon(
                              icon,
                              color: iconColor,
                              size: iconSize,
                            ))
                        : Container(),
                    label != null
                        ? Expanded(
                            child: Container(
                                color: Colors.transparent,
                                alignment: alignmentLabel ?? Alignment.center,
                                child: Text(
                                  label!,
                                  style: styleLabel ?? XStyles.xStyleText(fontSize: 13, colorText: textColor),
                                  textAlign: textAlignLabel ?? TextAlign.center,
                                )))
                        : Container(),
                  ],
                ),
        ));
  }
}
